simplify.ApiError

Package simplify :: Class ApiError |
[hide private]
[frames] | no frames]

# Class ApiError

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                                  ApiError

Base class for all API errors.

Instance Methods | [hide private]
__init__(self, message=None, status=500, error_data=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
describe(self) Returns a string describing the error. | source code
Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Instance Variables | [hide private]
| error_code string code for the error (or None if there is no error code).
| error_data dictionary containing all the error data (or None if there is no data)
| message string description of the error (or None if there is no message).
| reference reference for the error (or None if there is no reference).
| status HTTP status code (or None if there is no status).

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, message=None, status=500, error_data=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### describe(self) | source code
Returns a string describing the error. Returns: a string describing the error.